camelot.camelot.model.authentication.Organization

Package camelot :: Package camelot :: Package model :: Module authentication :: Class Organization |
[hide private]
[frames] | no frames]

# Class Organization

source code

An organization represents any internal or external organization. Organizations can include businesses and groups of individuals

Nested Classes | [hide private]
| Admin

Instance Methods | [hide private]
__unicode__(self) | source code
number_of_shares_issued(self) | source code

Class Variables | [hide private]
| name = `Field(Unicode(50), required= True, index= True)`
| logo = `Field(camelot.types.Image(upload_to= 'organization-logo`...``
| tax_id = `Field(Unicode(20))`
| directors = `OneToMany('DirectedDirector', inverse= 'establishe`...``
| employees = `OneToMany('EmployerEmployee', inverse= 'establishe`...``
| suppliers = `OneToMany('SupplierCustomer', inverse= 'establishe`...``
| customers = `OneToMany('SupplierCustomer', inverse= 'establishe`...``
| shareholders = `OneToMany('SharedShareholder', inverse= 'establ`...``
| shares = `OneToMany('SharedShareholder', inverse= 'established_`...``
Inherited from `Party`: `addresses`, `contact_mechanisms`

Method Details | [hide private]

### number_of_shares_issued(self) | source code
Decorators: `@property`

Class Variable Details | [hide private]

  ### logo Value:
      Field(camelot.types.Image(upload_to= 'organization-logo'), deferred= T
      rue)

  ### directors Value:
      OneToMany('DirectedDirector', inverse= 'established_from')

  ### employees Value:
      OneToMany('EmployerEmployee', inverse= 'established_from')

  ### suppliers Value:
      OneToMany('SupplierCustomer', inverse= 'established_to')

  ### customers Value:
      OneToMany('SupplierCustomer', inverse= 'established_from')

  ### shareholders Value:
      OneToMany('SharedShareholder', inverse= 'established_from')

  ### shares Value:
      OneToMany('SharedShareholder', inverse= 'established_to')